Changelog
=========

3.0
-------
#. Registered library with PYPI, renamed repo to django-inline-wrestler since django-inline-orderable was taken :)
#. Add table column width alignment
#. Added sorting by column values
#. Fixed bug where new item is added at second-to-last position

